preprocess_file

Function preprocess_file 

pub fn preprocess_file<P: AsRef<Path>>(path: P) -> Result<Array4<f32>>
Load and preprocess an image from a file path.

Errors

Returns an error if the image cannot be loaded.