pub fn ensure_model_downloaded<P: AsRef<Path>>(
storage_dir: P,
) -> Result<PathBuf>Expand description
Ensures the model exists at the given path. If not, downloads it.
Errors
Returns an error if the directory cannot be created, the download fails, or the file cannot be written.